@@ -69,7 +69,7 @@ class TestHawkAuth(unittest.TestCase):
     def test_server_url_is_parsed(self):
         auth = HawkAuth(hawk_session=codecs.encode(b"hello", "hex_codec"),
                         server_url="http://localhost:5000")
-        self.assertEquals(auth.host, "localhost:5000")
+        self.assertEqual(auth.host, "localhost:5000")
 
     def test_hawk_auth_can_handle_a_timestamp_argument(self):
         auth = HawkAuth(hawk_session=codecs.encode(b"hello", "hex_codec"),
